from setuptools import setup

setup(name='gaussian_binom_dist',
      version='0.1',
      description='Gaussian distributions and binomial distributions',
      packages=['gaussian_binom_dist'],
      author="Cihan Evren",
      author_email="cihan.evren2@outlook.com",
      zip_safe=False)
